@@ -153,14 +153,15 @@ def pip_cert(tmp_path_factory):
     # workaround for https://github.com/pypa/pip/issues/8984 - if the certificate is explicitly set no error can happen
     key = ensure_str("PIP_CERT")
     if key in os.environ:
-        return
-    cert = tmp_path_factory.mktemp("folder") / "cert"
-    import pkgutil
-
-    cert_data = pkgutil.get_data("pip._vendor.certifi", "cacert.pem")
-    cert.write_bytes(cert_data)
-    with change_os_environ(key, str(cert)):
         yield
+    else:
+        cert = tmp_path_factory.mktemp("folder") / "cert"
+        import pkgutil
+
+        cert_data = pkgutil.get_data("pip._vendor.certifi", "cacert.pem")
+        cert.write_bytes(cert_data)
+        with change_os_environ(key, str(cert)):
+            yield
 
 
 @pytest.fixture(autouse=True)
@@ -224,8 +225,8 @@ def coverage_env(monkeypatch, link, request):
         # we inject right after creation, we cannot collect coverage on site.py - used for helper scripts, such as debug
         from virtualenv import run
 
-        def _session_via_cli(args, options, setup_logging):
-            session = prev_run(args, options, setup_logging)
+        def _session_via_cli(args, options, setup_logging, env=None):
+            session = prev_run(args, options, setup_logging, env)
             old_run = session.creator.run
 
             def create_run():
